@@ -165,7 +165,7 @@ class Client:
                 self.logger.info(f'\t{k} - setting to default value of {default_config[k]}')
 
         # Check command line argvs
-        parse_flag = lambda s: (str(s).lower() == 'true') 
+        parse_flag = lambda s: (str(s).lower() == 'true')
 
         if simulation_flag is None:
             self.simulation_flag = parse_flag(self.config['simulation'])
@@ -204,6 +204,13 @@ class Client:
             self.exch_port = exch_port
             self.config['exch_port'] = exch_port
 
+        self.url_path = self.config.get('url_path', "")
+
+        if self.url_path != "":
+            self.reg_addr = f"{self.aggr_ip}:{self.reg_port}/{self.url_path}/reg"
+        else:
+            self.reg_addr = f'{self.aggr_ip}:{self.reg_port}'
+
         if token is None:
             self.token = self.config['token']
         else:
@@ -307,12 +314,12 @@ class Client:
             # Create a participation message
             msg = generate_participate_message(self)
 
-            resp = await self.comm_handler.send_msg(msg, f'{self.aggr_ip}:{self.reg_port}')
+            resp = await self.comm_handler.send_msg(msg, self.reg_addr)
 
             if self.agent_running:
                 while (resp[0] == AggMsgType.welcome):
                     await asyncio.sleep(5)
-                    resp = await self.comm_handler.send_msg(msg, f'{self.aggr_ip}:{self.reg_port}')
+                    resp = await self.comm_handler.send_msg(msg, self.reg_addr)
 
             if resp[0] == AggMsgType.welcome:
                 # Parse the response message
@@ -380,23 +387,22 @@ class Client:
             compatible_data_dict_read(data_dict)
         self.logger.debug(models)
 
-        wsaddr = f'{self.wsprefix}{self.reg_port}'
         try:
             # Create an initialize model message
             msg = generate_initialize_model_message(self, model_id, models, gene_time, performance_dict,
                                                     base_model)
-            resp = await self.comm_handler.send_msg(msg, f'{self.aggr_ip}:{self.reg_port}', resp_required=True)
+            resp = await self.comm_handler.send_msg(msg, self.reg_addr, resp_required=True)
 
             if resp[0] == AggMsgType.max_size_reached:
                 self.isRegistered = False
                 self.logger.error(f"--- Aggregator Response: {resp[1]}, system exits. ---")
                 raise MaxSizeReachedError(resp[1])
-            
+
             elif resp[0] == AggMsgType.not_opt:
                 self.isRegistered = False
                 self.logger.error(f"--- Aggregator Response: {resp[1]} ---")
                 raise AggRejectionError(resp[1])
-            
+
             self.logger.info("Base model uploaded to aggregator")
         except Exception as e:
             self.logger.error(f"--- Cannot connect to the aggregator: {e} ---")
@@ -418,6 +424,13 @@ class Client:
             self.logger.debug(f'--- this is an infinite model exchange routine ---')
 
         loop_count = 0
+
+        if self.url_path != "":
+            # NOTE: reg_port is used here because reg_port should be https(443/tcp) and that should be the same for msend_port also.
+            self.msend_addr = f"{self.aggr_ip}:{self.reg_port}/{self.url_path}/recv"
+        else:
+            self.msend_addr = f'{self.aggr_ip}:{self.msend_port}'
+
         while self.exch_active:
 
             # Number of iterations if clearly specified by users
@@ -448,8 +461,8 @@ class Client:
                     self.id, model_id, models, performance_dict, self.num_samples)
 
                 try:
-                    resp = await self.comm_handler.send_msg(upd_msg, f'{self.aggr_ip}:{self.msend_port}', resp_required=True)
-                    
+                    resp = await self.comm_handler.send_msg(upd_msg, self.msend_addr, resp_required=True)
+
                     if resp[0] == AggMsgType.max_agents_reached:
                         self.logger.error(f"--- Aggregator Response: {resp[1]}---")
                         raise MaxAgentsReachedError(resp[1])
@@ -461,7 +474,7 @@ class Client:
                     elif resp[0] == AggMsgType.not_opt:
                         self.logger.error(f"--- Aggregator Response: {resp[1]} ---")
                         raise AggRejectionError(resp[1])
-                    
+
                     elif resp[0] == AggMsgType.max_size_reached:
                         self.isRegistered = False
                         self.logger.error(f"--- Aggregator Response: {resp[1]}, system exits. ---")
@@ -489,7 +502,7 @@ class Client:
                 msg.append(self.exch_active)
 
                 try:
-                    resp = await self.comm_handler.send_msg(msg, f'{self.aggr_ip}:{self.msend_port}')
+                    resp = await self.comm_handler.send_msg(msg, self.msend_addr)
 
                     if resp[0] == AggMsgType.update:
                         self.logger.debug(f'--- SG Model Received ---')
