@@ -65,11 +65,11 @@ class CommunicationHandler():
                 resp = pickle.loads(await websocket.recv())
                 return resp
 
-        elif self.protocol == 'http':
-            url = f"{'https' if self.ssl else 'http'}://{addr}"
+        elif self.protocol in ['http', 'https'] :
+            url = f"{self.protocol}://{addr}"
 
             async with aiohttp.ClientSession() as session:
-                encoded_resp = await session.post(url, data=msg, ssl=self.ssl_context)
+                encoded_resp = await session.post(url, data=msg, ssl=False)
                 resp = pickle.loads(await encoded_resp.content.read())
                 return resp
 
